pub struct Provider {
pub name: String,
pub description: Option<String>,
pub roles: Option<Vec<String>>,
pub url: Option<String>,
pub additional_fields: Map<String, Value>,
}Expand description
This object provides information about a provider.
A provider is any of the organizations that captures or processes the
content of the Collection and therefore influences the
data offered by this Collection. May also include information about the
final storage provider hosting the data.
Fields
name: StringThe name of the organization or the individual.
description: Option<String>Multi-line description to add further provider information such as processing details for processors and producers, hosting details for hosts or basic contact information.
CommonMark 0.29 syntax MAY be used for rich text representation.
roles: Option<Vec<String>>Roles of the provider.
Any of "licensor", "producer", "processor", or "host".
url: Option<String>Homepage on which the provider describes the dataset and publishes contact information.
additional_fields: Map<String, Value>Additional fields on the provider.
Implementations