#[non_exhaustive]pub enum Error {
Show 38 variants
CannotConvertQueryToString(Map<String, Value>),
CannotConvertCql2JsonToString(Map<String, Value>),
ChronoParse(ParseError),
Cql2(Box<Error>),
Geojson(Box<Error>),
EmptyDatetimeInterval,
FeatureNotEnabled(&'static str),
IncorrectType {
actual: String,
expected: String,
},
InvalidAttribute(String),
InvalidBbox(Vec<f64>, &'static str),
InvalidDatetime(String),
InvalidFilePath(String),
Io(Error),
MissingField(&'static str),
NoHref,
NoItems,
NotAnObject(Value),
ParseIntError(ParseIntError),
ParseFloatError(ParseFloatError),
SearchHasBboxAndIntersects(Box<Search>),
SerdeJson(Error),
SerdeUrlencodedSer(Error),
StartIsAfterEnd(DateTime<FixedOffset>, DateTime<FixedOffset>),
TryFromInt(TryFromIntError),
UnknownType(String),
Unimplemented(&'static str),
UnsupportedGeoparquetType,
UnsupportedMigration(Version, Version),
UrlParse(ParseError),
Arrow(ArrowError),
ArrowSchemaMismatch,
GeoArrow(GeoArrowError),
Wkb(WkbError),
ArrowAdapterClient(Box<dyn Error + Send + Sync>),
MissingGeoparquetMetadata,
Parquet(ParquetError),
InvalidYear(i32),
UnrecognizedDateFormat(String),
}Expand description
Error enum for crate-specific errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CannotConvertQueryToString(Map<String, Value>)
Queries cannot be converted to strings.
CannotConvertCql2JsonToString(Map<String, Value>)
CQL2 JSON cannot (currently) be converted to strings.
TODO support conversion
ChronoParse(ParseError)
Cql2(Box<Error>)
Geojson(Box<Error>)
EmptyDatetimeInterval
An empty datetime interval.
FeatureNotEnabled(&'static str)
Some functionality requires a certain optional feature to be enabled.
IncorrectType
Returned when a STAC object has the wrong type field.
InvalidAttribute(String)
Returned when a property name conflicts with a top-level STAC field, or it’s an invalid top-level field name.
InvalidBbox(Vec<f64>, &'static str)
This vector is not a valid bounding box.
InvalidDatetime(String)
This string is not a valid datetime interval.
InvalidFilePath(String)
A file path could not be converted to a URL.
Io(Error)
MissingField(&'static str)
Returned when there is not a required field on a STAC object
NoHref
There is not an href, when an href is required.
NoItems
There are no items, when items are required.
NotAnObject(Value)
This is not a JSON object.
ParseIntError(ParseIntError)
ParseFloatError(ParseFloatError)
SearchHasBboxAndIntersects(Box<Search>)
A search has both bbox and intersects.
SerdeJson(Error)
SerdeUrlencodedSer(Error)
StartIsAfterEnd(DateTime<FixedOffset>, DateTime<FixedOffset>)
The start time is after the end time.
TryFromInt(TryFromIntError)
UnknownType(String)
Returned when the type field of a STAC object does not equal "Feature", "Catalog", or "Collection".
Unimplemented(&'static str)
This functionality is not yet implemented.
UnsupportedGeoparquetType
Unsupported geoparquet type
UnsupportedMigration(Version, Version)
Unsupported migration.
UrlParse(ParseError)
Arrow(ArrowError)
ArrowSchemaMismatch
The schema of two sets of items don’t match.
GeoArrow(GeoArrowError)
Wkb(WkbError)
ArrowAdapterClient(Box<dyn Error + Send + Sync>)
Error from a wrapped client used by Arrow adapters.
MissingGeoparquetMetadata
No geoparquet metadata in a stac-geoparquet file.
Parquet(ParquetError)
InvalidYear(i32)
Invalid year value.
UnrecognizedDateFormat(String)
Unrecognized date format.